@@ -13,7 +13,26 @@ logger = logging.getLogger(__name__)
 DEFAULT_PORT = 5500
 
 
-def live_reload(files=None, port=DEFAULT_PORT, throttle=3, fns=None, reload=True, callback=None):
+def live_reload(files=None, port=DEFAULT_PORT):
+    """
+    Start python livereload server, watching
+    the given files
+
+    :param files: Files to watch
+    :param port: Port to run server on
+    :return: void
+    """
+    def run_server():
+        logger.info("Loading livereload server on port %d", port)
+        s = server.Server()
+        for f in files or []:
+            s.watch(f)
+        s.serve(port=port)
+    thread.start_new_thread(run_server, ())
+    register_keep_alive()
+
+
+def live_reload_watch(files=None, port=DEFAULT_PORT, throttle=3, fns=None, reload=True, callback=None):
     """
     Start python livereload server, watching
     the given files using fabuild's watch function.  This
@@ -55,22 +74,3 @@ def live_reload(files=None, port=DEFAULT_PORT, throttle=3, fns=None, reload=True
           recursive=True, throttle=throttle, keep_alive=True)
 
 
-def live_reload_simple(files=None, port=DEFAULT_PORT):
-    """
-    Start python livereload server, watching
-    the given files
-
-    :param files: Files to watch
-    :param port: Port to run server on
-    :return: void
-    """
-    def run_server():
-        logger.info("Loading livereload server on port %d", port)
-        s = server.Server()
-        for f in files or []:
-            s.watch(f)
-        s.serve(port=port)
-    thread.start_new_thread(run_server, ())
-    register_keep_alive()
-
-
