@@ -20,7 +20,10 @@ def stylus(cmd='stylus', fns=None, watch=False):
 
     logger.debug("Running stylus function.")
 
-    build_run(cmd + ' ' + ' '.join([f for f in get_files('**.styl')]))
+    files = [f for f in get_files('**.styl')]
+
+    if files:
+        build_run(cmd + ' ' + ' '.join(files))
 
     if watch:
         def callback(event, watcher):
